==> drf_tree_router-0.1.1-py3-none-any.whl: README.md <==
# Django REST Framework Tree Router

[![Coverage Status][coverage-badge]][coverage]
[![GitHub Workflow Status][status-badge]][status]
[![PyPI][pypi-badge]][pypi]
[![GitHub][licence-badge]][licence]
[![GitHub Last Commit][repo-badge]][repo]
[![GitHub Issues][issues-badge]][issues]
[![Python Version][version-badge]][pypi]

```shell
pip install drf-tree-router
```

---

**Documentation**: [https://mrthearman.github.io/drf-tree-router/](https://mrthearman.github.io/drf-tree-router/)

**Source Code**: [https://github.com/MrThearMan/drf-tree-router/](https://github.com/MrThearMan/drf-tree-router/)

---

A Django REST Framework router that can be nested with other routers to create a tree-like structure
of your API endpoints. The router also accepts APIViews in addition to ViewSets.

[coverage-badge]: https://coveralls.io/repos/github/MrThearMan/drf-tree-router/badge.svg?branch=main
[status-badge]: https://img.shields.io/github/workflow/status/MrThearMan/drf-tree-router/Tests
[pypi-badge]: https://img.shields.io/pypi/v/drf-tree-router
[licence-badge]: https://img.shields.io/github/license/MrThearMan/drf-tree-router
[repo-badge]: https://img.shields.io/github/last-commit/MrThearMan/drf-tree-router
[issues-badge]: https://img.shields.io/github/issues-raw/MrThearMan/drf-tree-router
[version-badge]: https://img.shields.io/pypi/pyversions/drf-tree-router

[coverage]: https://coveralls.io/github/MrThearMan/drf-tree-router?branch=main
[status]: https://github.com/MrThearMan/drf-tree-router/actions/workflows/main.yml
[pypi]: https://pypi.org/project/drf-tree-router
[licence]: https://github.com/MrThearMan/drf-tree-router/blob/main/LICENSE
[repo]: https://github.com/MrThearMan/drf-tree-router/commits/main
[issues]: https://github.com/MrThearMan/drf-tree-router/issues

==> drf_tree_router-0.2.1-py3-none-any.whl: README.md <==
# Django REST Framework Tree Router

[![Coverage Status][coverage-badge]][coverage]
[![GitHub Workflow Status][status-badge]][status]
[![PyPI][pypi-badge]][pypi]
[![GitHub][licence-badge]][licence]
[![GitHub Last Commit][repo-badge]][repo]
[![GitHub Issues][issues-badge]][issues]
[![Downloads][downloads-badge]][pypi]

[![Python Version][version-badge]][pypi]
[![Django Version][django-badge]][pypi]
[![DRF Version][drf-badge]][pypi]

```shell
pip install drf-tree-router
```

---

**Documentation**: [https://mrthearman.github.io/drf-tree-router/](https://mrthearman.github.io/drf-tree-router/)

**Source Code**: [https://github.com/MrThearMan/drf-tree-router/](https://github.com/MrThearMan/drf-tree-router/)

---

A Django REST Framework router that can be nested with other routers to create a tree-like structure
of your API endpoints. The router also accepts APIViews in addition to ViewSets.


[coverage-badge]: https://coveralls.io/repos/github/MrThearMan/drf-tree-router/badge.svg?branch=main
[status-badge]: https://img.shields.io/github/workflow/status/MrThearMan/drf-tree-router/Test
[pypi-badge]: https://img.shields.io/pypi/v/drf-tree-router
[licence-badge]: https://img.shields.io/github/license/MrThearMan/drf-tree-router
[repo-badge]: https://img.shields.io/github/last-commit/MrThearMan/drf-tree-router
[issues-badge]: https://img.shields.io/github/issues-raw/MrThearMan/drf-tree-router
[version-badge]: https://img.shields.io/pypi/pyversions/drf-tree-router
[downloads-badge]: https://img.shields.io/pypi/dm/drf-tree-router
[django-badge]: https://img.shields.io/pypi/djversions/drf-tree-router
[drf-badge]: https://img.shields.io/badge/drf%20versions-3.7.0%20--%203.12.0-blue

[coverage]: https://coveralls.io/github/MrThearMan/drf-tree-router?branch=main
[status]: https://github.com/MrThearMan/drf-tree-router/actions/workflows/test.yml
[pypi]: https://pypi.org/project/drf-tree-router
[licence]: https://github.com/MrThearMan/drf-tree-router/blob/main/LICENSE
[repo]: https://github.com/MrThearMan/drf-tree-router/commits/main
[issues]: https://github.com/MrThearMan/drf-tree-router/issues
